# Forecast-elicitation-Mechanism

Implement 4 papers:

- Water from Two Rocks: Maximizing the Mutual Information (wftr)
- Dominantly Truthful Multi-task Peer Prediction with a Constant Number of Tasks (dmi)
- A Bayesian truth serum for subjective data (BTS)
- Informed Truthfulness in Multi-Task Peer Prediction (CA)
